@@ -274,9 +274,11 @@ def image_preview(img, is_url=False, set_proxy: str = '', set_referer: str = '',
         if not is_url and isinstance(img, str):
             is_url = img.startswith('http')
         if is_url:
-            from PIL import Image
+            # from PIL import Image
+            from .. import requirePackage
             from io import BytesIO
             import requests
+            Image = requirePackage('PIL', 'Image', 'Pillow')
             if set_referer:
                 headers['referer'] = set_referer
             proxies = {
@@ -295,7 +297,7 @@ def image_preview(img, is_url=False, set_proxy: str = '', set_referer: str = '',
         _real_height = real_height(buf)
         _real_width = math.ceil(width / height * _real_height) * 2 + 1
 
-        qs_default_console.print(' ' * int(max((qs_default_console.width - _real_width) / 2, 0)), end='')
+        qs_default_console.print(' ' * int(max((qs_default_console.width - _real_width) / 2 - 1, 0)), end='')
 
         imgcat(buf, height=real_height(buf))
     except Exception as e:
