@@ -40,7 +40,7 @@ def requirePackage(pname: str, module: str = "", real_name: str = "", not_exit:
     """
     try:
         exec(f'from {pname} import {module}' if module else f"import {pname}")
-    except:
+    except Exception:
         from PyInquirer import prompt
 
         confirm = prompt({
@@ -51,10 +51,10 @@ def requirePackage(pname: str, module: str = "", real_name: str = "", not_exit:
             'default': True})['install']
         if confirm:
             os.system(f'pip3 install {pname if not real_name else real_name}')
-            qs_default_console.print(qs_info_string, f'just run again: "{" ".join(sys.argv)}"')
             if not_exit:
                 exec(f'from {pname} import {module}' if module else f"import {pname}")
             else:
+                qs_default_console.print(qs_info_string, f'just run again: "{" ".join(sys.argv)}"')
                 exit(0)
         else:
             exit(-1)
@@ -142,7 +142,7 @@ def cur_time():
     qs_default_console.print(qs_info_string, ' '.join(tm))
 
 
-def u(argv: list = None):
+def open_url(argv: list = None):
     """
     打开命令行参数中的链接
 
@@ -237,3 +237,21 @@ def pcat():
     :return: None
     """
     print(requirePackage('pyperclip', 'paste')())
+
+
+def fcopy():
+    """
+    获取文件内容并复制进粘贴板
+
+    Get the content of the file and copy it into the pasteboard
+    :return:
+    """
+    if not os.path.exists(sys.argv[2]):
+        return qs_default_console.print(qs_error_string, "No such file:" if user_lang != 'zh' else '未找到文件:', sys.argv[2])
+    with open(sys.argv[2], 'r') as f:
+        requirePackage('pyperclip').copy(f.read())
+
+
+def get_user_lang():
+    print(user_lang)
+
