@@ -353,16 +353,6 @@ def weather():
         print('Error: Get data failed.' if user_lang != 'zh' else '错误: 获取数据失败')
 
 
-def ipinfo(ip: str = None):
-    """
-    通过ipinfo查ip（定位不准）
-
-    Check IP via IPInfo (incorrect location)
-    """
-    from .API.IpInfo import get_ip_info
-    return get_ip_info(ip)
-
-
 def largeImage():
     """
     百度图片效果增强
@@ -509,18 +499,29 @@ def short_video_info(son_call=False):
         'cover': 'Cover ' if user_lang != 'zh' else '封面',
         'source': 'Source' if user_lang != 'zh' else '来源'
     }
-    status, res = short_video_info(url.strip('/'))
-    if not status:
-        qs_default_console.print(qs_info_string, res['title'] + ':' + res['source'])
-        return status
-    qs_default_console.print(qs_info_string, '[{}] {}'.format(output_prefix['title'], res['title']))
-    sz = int(get_fileinfo(res['video_url'])[-1].headers['content-length']) if not son_call else -1
-    qs_default_console.print(qs_info_string,
-                             '[{}] {}\n{}'.format(output_prefix['video'], size_format(sz, True) if sz > 0 else '--',
-                                                  res['video_url']))
-    sz = int(get_fileinfo(res['cover_url'])[-1].headers['content-length'])
-    qs_default_console.print(qs_info_string,
-                             '[{}] {}\n{}'.format(output_prefix['cover'], size_format(sz, True), res['cover_url']))
+    with qs_default_console.status('正在获取视频信息') as _:
+        status, res = short_video_info(url.strip('/'))
+        if not status:
+            qs_default_console.print(qs_info_string, res['title'] + ':' + res['source'])
+            return status
+        showStatus = '-url' in sys.argv
+        qs_default_console.print(qs_info_string, '[{}] {}'.format(output_prefix['title'], res['title']))
+        if res['video_url']:
+            sz = int(get_fileinfo(res['video_url'])[-1].headers['content-length']) if not son_call else -1
+            qs_default_console.print(
+                qs_info_string,
+                '[{}] {}\n{}'.format(
+                    output_prefix['video'],
+                    size_format(sz, True) if sz > 0 else '--',
+                    res['video_url'] if showStatus else ''
+                )
+            )
+        if showStatus:
+            sz = int(get_fileinfo(res['cover_url'])[-1].headers['content-length'])
+            qs_default_console.print(
+                qs_info_string,
+                '[{}] {}\n{}'.format(output_prefix['cover'], size_format(sz, True), res['cover_url'] if showStatus else '')
+            )
     if system == 'darwin':
         from .ImageTools.ImagePreview import image_preview
         image_preview(res['cover_url'], True)
@@ -540,14 +541,24 @@ def short_video_dl():
     from .NetTools.NormalDL import normal_dl
     from .ImageTools.VideoTools import tomp4
     from . import remove
+
     res = short_video_info(son_call=True)
 
     if not res:
         qs_default_console.print(qs_error_string, 'Download failed' if user_lang != 'zh' else '下载失败')
         return
-    normal_dl(res['video_url'], set_name=res['title'] if res['title'] else 'UnknownTitle')
-    tomp4(res['title'] if res['title'] else 'UnknownTitle')
-    remove(res['title'] if res['title'] else 'UnknownTitle')
+
+    fileName = res['title'] if res['title'] else 'UnknownTitle'
+    if 'pics' in res and res['pics']:
+        from .ImageTools.ImageTools import topng
+        for index, url in enumerate(res['pics']):
+            normal_dl(url, set_name=fileName + str(index + 1))
+            topng(fileName + str(index + 1))
+            remove(fileName + str(index + 1))
+    elif res['video_url']:
+        normal_dl(res['video_url'], set_name=fileName)
+        tomp4(fileName)
+        remove(fileName)
 
 
 def acg():
@@ -743,35 +754,9 @@ def pinyin():
     qs_default_console.print(qs_info_string if status else qs_error_string, res)
 
 
-def photo():
-    from .API.SimpleAPI import photo
-
-    st = qs_default_console.status('Requesting data..' if user_lang != 'zh' else '请求数据中..')
-    st.start()
-
-    try:
-        status, acg_link, name = photo()
-        qs_default_console.print(qs_info_string, f"{'链接' if user_lang == 'zh' else 'LINK'}: {acg_link}") \
-            if status else qs_default_console.log(qs_error_string, acg_link)
-        if status:
-            if '-save' in sys.argv[2:]:
-                from .NetTools.NormalDL import normal_dl
-                st.stop()
-                acg_link = normal_dl(acg_link)
-            if system == 'darwin':  # Only support iTerm for Mac OS X
-                from .ImageTools.ImagePreview import image_preview
-                st.update(status='Loading image...' if user_lang != 'zh' else '加载图片中..')
-                image_preview(open(acg_link) if '-save' in sys.argv[2:] else acg_link,
-                              '-save' not in sys.argv[2:], qs_console_status=st)
-    except Exception as e:
-        qs_default_console.print(qs_error_string, repr(e))
-    finally:
-        st.stop()
-
-
 def setu():
     import random
-    random.choice([acg, loli, photo])()
+    random.choice([acg, loli])()
 
 
 def exchange():
@@ -827,11 +812,11 @@ def wallhaven():
 
     url, oneFlag = '', False
     if '-h' in sys.argv:
-        return qs_default_console.print(qs_info_string, "Usage: qs wallhaven [-u <url>] [-one] [-save]")
+        return qs_default_console.print(qs_info_string, "Usage: qs wallhaven [-open_url <url>] [-one] [-save]")
 
-    if '-u' in sys.argv:
-        url = sys.argv[sys.argv.index('-u') + 1]
-        sys.argv.remove('-u')
+    if '-open_url' in sys.argv:
+        url = sys.argv[sys.argv.index('-open_url') + 1]
+        sys.argv.remove('-open_url')
         sys.argv.remove(url)
 
     oneFlag = '-one' in sys.argv
@@ -949,3 +934,36 @@ def daily60s():
             cur_index = index
             time.sleep(len_ls[index])
     dealSignal()
+
+
+def m2t():
+    """
+    磁力链接转种子文件
+
+    Magnet link to Torrent file
+    :return:
+    """
+    import re
+
+    if '-f' in sys.argv:
+        file_path = sys.argv[sys.argv.index('-f') + 1]
+        with open(file_path, 'r') as f:
+            contents = f.read()
+    elif '-u' in sys.argv:
+        contents = sys.argv[sys.argv.index('-u') + 1]
+    else:
+        import pyperclip
+        contents = pyperclip.paste()
+    urls = re.findall('magnet:\?xt=urn:btih:(.*)', contents)
+    if len(urls) > 1:
+        from PyInquirer import prompt
+        url = prompt({
+            'type': 'list',
+            'name': 'hash',
+            'message': 'Select hash code | 选择哈希码:',
+            'choices': urls
+        })['hash']
+    else:
+        url = urls[0]
+    from .API.Lolicon import magnet2torrent
+    magnet2torrent(url)
