@@ -46,14 +46,18 @@ def base_menu():
     qs f   <file...>         :-> open file by default app
     qs cal <exp>             :-> calculate exp
     qs time                  :-> view current time
-    qs pact                  :-> output string in clipboard""") \
+    qs pact                  :-> output string in clipboard
+    qs fcopy <file>          :-> copy file content to clipboard
+    qs user_lang             :-> Get User Language in .qsrc""") \
         if user_lang != 'zh' else color_rep("""基础工具:
     qs u   <url...>          :-> 使用默认浏览器打开多个链接
     qs a   <app> \[file..]    :-> 打开应用或使用应用打开文件 (仅支持Mac OS)
     qs f   <file...>         :-> 使用合适的应用打开文件
     qs cal <exp>             :-> 计算算术表达式
     qs time                  :-> 查看当前时间
-    qs pcat                  :-> 输出粘贴板内容""")
+    qs pcat                  :-> 输出粘贴板内容
+    qs fcopy <file>          :-> 拷贝文件内容到粘贴板
+    qs user_lang             :-> 获取用户的默认语言""")
 
 
 def system_menu():
@@ -128,10 +132,9 @@ def api_menu():
     qs pasteme <method> [*]  :-> get with key, [password] or post clipboard content
     qs bcv   <url/video code> :-> get Bilibili video cover image with <url>
     qs gbc   <garbage...>     :-> check Chinese garbage classification
-    qs svi   <url>            :-> get short video info
+    qs svi   <url> \[-url]     :-> get short video info (show url)
     qs svd   <url>            :-> download short video info as mp4
     qs acg   [-save]          :-> get an acg image link (or save)
-    qs photo [-save]          :-> get an porn photo link (or save)
     qs bing  [-save]          :-> get an bing image link (or save)
     qs phi   <url>            :-> get <image url> in url (preview on Mac)
     qs kd    <courier number> :-> Query China express
@@ -141,7 +144,8 @@ def api_menu():
     qs zhihu                 :-> Get zhihu.com Daily
     qs wallhaven [-save]     :-> Get Wallhaven Toplist
     qs lmgtfy <keywords>     :-> Get LMGTFY link for keywords
-    qs d60                   :-> Get the daily 60-second morning report""")\
+    qs d60                   :-> Get the daily 60-second morning report
+    qs m2t < -f path | -u link | * > :-> transform magnet link to torrent file""")\
         if user_lang != 'zh' else color_rep("""API工具:
     qs trans  \[content]       :-> 翻译命令参数或剪切板中的内容
     qs pinyin \[content]      :-> 获取中文内容的拼音
@@ -158,10 +162,9 @@ def api_menu():
     qs pasteme <method> [*]  :-> 通过pasteme get或post信息
     qs bcv   <url/video code> :-> 获取B站视频、直播封面图片
     qs gbc   <garbage...>     :-> 查询垃圾分类
-    qs svi   <url>            :-> 获取多平台短视频信息
+    qs svi   <url> \[-url]     :-> 获取多平台短视频信息 (展示链接)
     qs svd   <url>            :-> 下载多平台短视频为mp4
     qs acg   [-save]          :-> 获取一张acg图片链接 (或保存)
-    qs photo [-save]          :-> 获取一张涩图链接 (或保存)
     qs bing  [-save]          :-> 获取一张bing图片链接 (或保存)
     qs phi   <url>            :-> 获取url里的图片链接 (Mac上iTerm可预览)
     qs kd    <courier number> :-> 查询国内快递
@@ -171,7 +174,8 @@ def api_menu():
     qs zhihu                :-> 获取知乎日报
     qs wallhaven [-save]     :-> 获取Wallhaven Top动漫涩图
     qs lmgtfy <keywords>     :-> 获取关键词的LMGTFY链接
-    qs d60                   :-> 获取每日60秒早报""")
+    qs d60                   :-> 获取每日60秒早报
+    qs m2t < -f path | -u link | * > :-> 转换磁力链接为种子文件""")
 
 
 def image_menu():
@@ -182,14 +186,22 @@ def image_menu():
     qs v2gif <path> \[sz] \[fps] :-> generate gif from video
     qs v2mp4 <video>         :-> format video to mp4
     qs v2mp3 <video>         :-> extract audio from video and save in MP3
-    qs rmaudio <video>       :-> remove audio in video (return mp4 only)""") \
+    qs rmaudio <video>       :-> remove audio in video (return mp4 only)
+    qs i2png <imgs...>       :-> transform imgs to png
+    qs i2jpg <imgs...>       :-> transform imgs to jpg
+    qs fmti <pic> <to> \[exp...] :-> format image to <to> color except \[exp...] color
+    qs vsta    <video> <audio> :-> set video's audio""") \
         if user_lang != 'zh' else color_rep("""图像处理:
-    qs stbg <pic> <to> \[from]    :-> 替换图片颜色 (from默认为透明)
-    qs icat <img>            :-> 在终端预览图片
-    qs v2gif <path> \[sz] \[fps] :-> 将视频导出为gif
-    qs v2mp4 <video>         :-> 将视频导出为mp4
-    qs v2mp3 <video>         :-> 提取视频音频为mp3
-    qs rmaudio <video>       :-> 删除mp4文件音频""")
+    qs stbg    <pic> <to> \[from]    :-> 替换图片颜色 (from默认为透明)
+    qs icat    <img>            :-> 在终端预览图片
+    qs v2gif   <path> \[sz] \[fps] :-> 将视频导出为gif
+    qs v2mp4   <video>         :-> 将视频导出为mp4
+    qs v2mp3   <video>         :-> 提取视频音频为mp3
+    qs rmaudio <video>       :-> 删除mp4文件音频
+    qs i2png   <imgs...>       :-> 将图像转换为png
+    qs i2jpg   <imgs...>       :-> 将图像转换为jpg
+    qs fmti    <pic> <to> \[exp...] :-> 格式化图片颜色为<to>，忽略\[exp...]颜色
+    qs vsta    <video> <audio> :-> 设置视频的音频""")
 
 
 menu_table = {
@@ -203,13 +215,15 @@ menu_table = {
 
 basic_funcs = {
     'self': 'basic',
-    'u': 'u',
+    'u': 'open_url',
     'a': 'open_app',
     'f': 'open_file',
     'i': 'init',
     'time': 'cur_time',
     'cal': 'calculate',
-    'pcat': 'pcat'
+    'pcat': 'pcat',
+    'fcopy': 'fcopy',
+    'user_lang': 'get_user_lang'
 }
 
 system_funcs = {
@@ -271,7 +285,8 @@ api_funcs = {
     'zhihu': 'zhihuDaily',
     'wallhaven': 'wallhaven',
     'lmgtfy': 'lmgtfy',
-    'd60': 'daily60s'
+    'd60': 'daily60s',
+    'm2t': 'm2t'
 }
 
 image_funcs = {
@@ -281,5 +296,9 @@ image_funcs = {
     'v2gif': 'v2gif',
     'rmaudio': 'remove_audio',
     'v2mp4': 'v2mp4',
-    'v2mp3': 'v2mp3'
+    'v2mp3': 'v2mp3',
+    'i2png': 'i2png',
+    'i2jpg': 'i2jpg',
+    'fmti': 'fmt_img_color',
+    'vsta': 'vsta'
 }
